@@ -1,4 +1,5 @@
 import pandas as pd
+import pyranges as pr
 import numpy as np
 import sys
 import logging
@@ -24,33 +25,39 @@ def read_meth(filename, name, window, smoothen=5):
     """
     try:
         table = pd.read_csv(filename, sep="\t")
+        gr = pr.PyRanges(table.rename(columns={"start": "Start", "chromosome": "Chromosome",
+                                               "end": "End", "Strand": "strand"}))
         logging.info("Read the file in a dataframe.")
+
         if window:
-            table = table.loc[(table["chromosome"] == window.chromosome) &
-                              table["start"].between(window.begin, window.end)]
-        table["pos"] = np.floor(table[['start', 'end']].mean(axis=1)).astype('i8')
+            gr = gr[window.chromosome, window.begin:window.end]
+        gr.pos = np.floor(gr.drop().df[["Start", "End"]].mean(axis=1))
+        table = gr.df
+
         if 'log_lik_ratio' in table:  # indicating the file is 'raw' or 'phased'
 
-            if 'PS' in table:  # indicating the file contains phased calls
+            table = table.drop(columns=['Start', 'End', 'log_lik_methylated',
+                                        'log_lik_unmethylated', 'num_calling_strands',
+                                        'num_motifs', 'sequence'])
+            if 'PS' in gr:  # indicating the file contains phased calls
                 data_type = 'phased'
                 logging.info("File contains phased raw data.")
             else:
                 data_type = 'raw'
                 logging.info("File contains raw data.")
             return Methylation(
-                table=table.drop(columns=['start', 'end', 'log_lik_methylated',
-                                          'log_lik_unmethylated', 'num_calling_strands',
-                                          'num_motifs', 'sequence'])
-                .sort_values(['read_name', 'pos']),
+                table=table.sort_values(['read_name', 'pos']),
                 data_type=data_type,
                 name=name,
                 called_sites=len(table))
         else:  # assuming the file is from calculate_methylation_frequency
             logging.info("File contains frequency data.")
+            called_sites = table.called_sites
+            table = table.drop(columns=['Start', 'End', 'num_motifs_in_group',
+                                        'called_sites', 'called_sites_methylated',
+                                        'group_sequence'])
             return Methylation(
-                table=table.drop(columns=['start', 'end', 'num_motifs_in_group',
-                                          'called_sites', 'called_sites_methylated',
-                                          'group_sequence'])
+                table=table
                 .sort_values('pos')
                 .groupby('pos')
                 .mean()
@@ -58,7 +65,7 @@ def read_meth(filename, name, window, smoothen=5):
                 .mean(),
                 data_type="frequency",
                 name=name,
-                called_sites=table["called_sites"].sum())
+                called_sites=called_sites.sum())
     except Exception:
         sys.stderr.write("\n\n\nInput file {} not recognized!\n".format(filename))
         sys.stderr.write("\n\n\nDetailed error:\n")
